@@ -22,8 +22,11 @@
 # Imports
 #
 from typing import Callable, Optional
+
 import pyrogram
+
 from telegram_periodic_msg_bot.misc.helpers import UserHelper
+from telegram_periodic_msg_bot.utils.pyrogram_wrapper import PyrogramWrapper
 from telegram_periodic_msg_bot.utils.wrapped_list import WrappedList
 
 
@@ -82,18 +85,18 @@ class ChatMembersGetter:
                       filter_fct: Optional[Callable[[pyrogram.types.ChatMember], bool]] = None,
                       filter_str: str = "all") -> ChatMembersList:
         # Get members
-        filtered_members = self.client.iter_chat_members(chat.id, filter=filter_str)
+        filtered_members = PyrogramWrapper.GetChatMembers(self.client, chat, filter_str)
         # Filter them if necessary
         if filter_fct is not None:
-            filtered_members = list(filter(filter_fct, filtered_members))
+            filtered_members = list(filter(filter_fct, filtered_members))   # type: ignore
         # Order filtered members
-        filtered_members.sort(
+        filtered_members.sort(      # type: ignore
             key=lambda member: member.user.username.lower() if member.user.username is not None else str(member.user.id)
         )
 
         # Build chat members
         chat_members = ChatMembersList()
-        chat_members.AddMultiple(filtered_members)
+        chat_members.AddMultiple(filtered_members)      # type: ignore
 
         return chat_members
 
