@@ -22,8 +22,11 @@
 # Imports
 #
 from typing import Optional
+
 import pyrogram
 
+from telegram_periodic_msg_bot.utils.pyrogram_wrapper import PyrogramWrapper
+
 
 #
 # Classes
@@ -34,7 +37,7 @@ class ChatHelper:
     # Get if channel
     @staticmethod
     def IsChannel(chat: pyrogram.types.Chat) -> bool:
-        return chat["type"] == "channel"
+        return PyrogramWrapper.IsChannel(chat)
 
     # Get title
     @staticmethod
@@ -50,6 +53,8 @@ class ChatHelper:
     @staticmethod
     def IsPrivateChat(chat: pyrogram.types.Chat,
                       user: pyrogram.types.User):
+        if ChatHelper.IsChannel(chat):
+            return False
         return chat.id == user.id
 
 
@@ -75,4 +80,4 @@ class UserHelper:
 
         if user.first_name is not None:
             return f"{user.first_name} {user.last_name}" if user.last_name is not None else f"{user.first_name}"
-        return user.last_name
+        return user.last_name if user.last_name is not None else ""
